==> nodejs_interop-0.8.0.tar.gz: test/node/child_process/child_process_module_test.dart <==
import 'dart:convert';
import 'dart:typed_data';
import 'package:nodejs_interop/node.dart';
import 'package:test/test.dart';

/// Tests the features of the [ChildProcessModule] class.
void main() => group('ChildProcessModule', () {
  final ChildProcessModule childProcess = require('child_process');

  group('.exec()', () {
    test('should run the given command and return its output', () async {
      var result = await fn1cb2ToFuture<String, String>(childProcess.exec, 'echo fooBar');
      expect(result.item1.trim(), equals('fooBar'));
    });

    test('should allow different output encodings', () async {
      var options = new SpawnOptions(encoding: BufferEncoding.buffer);
      var result = await fn2cb2ToFuture<Uint8List, Uint8List>(childProcess.exec, 'echo fooBar', options);
      expect(UTF8.decode(result.item1).trim(), equals('fooBar'));
    });
  });

  group('.execFile()', () {
    test('should run the given command and return its output', () async {
      var result = await fn2cb2ToFuture<String, String>(childProcess.execFile, process.execPath, const ['-v']);
      expect(result.item1.trim(), equals(process.version));
    });

    test('should allow different output encodings', () async {
      var options = new SpawnOptions(encoding: BufferEncoding.buffer);
      var result = await fn3cb2ToFuture<Uint8List, Uint8List>(childProcess.execFile, process.execPath, const ['-v'], options);
      expect(UTF8.decode(result.item1).trim(), equals(process.version));
    });
  });

  group('.execFileSync()', () {
    test('should run the given command and return its output', () {
      Uint8List stdout = childProcess.execFileSync(process.execPath, ['-v']);
      expect(UTF8.decode(stdout).trim(), equals(process.version));
    });

    test('should allow different output encodings', () {
      String stdout = childProcess.execFileSync(process.execPath, ['-v'], new SpawnOptions(encoding: BufferEncoding.utf8));
      expect(stdout.trim(), equals(process.version));
    });
  });

  group('.execSync()', () {
    test('should run the given command and return its output', () {
      Uint8List stdout = childProcess.execSync('echo fooBar');
      expect(UTF8.decode(stdout).trim(), equals('fooBar'));
    });

    test('should allow different output encodings', () {
      String stdout = childProcess.execSync('echo fooBar', new SpawnOptions(encoding: BufferEncoding.utf8));
      expect(stdout.trim(), equals('fooBar'));
    });
  });

  group('.fork()', () {
    test('should run the given JS module and return the spawned process', () async {
      var subprocess = childProcess.fork('test/fixtures/child_process.js', new SpawnOptions(silent: true));
      expect(subprocess.connected, isTrue);

      var stdout = (await asStream<Uint8List>(subprocess.stdout).toList()).single;
      expect(UTF8.decode(stdout).trim(), equals('fooBar'));
    });
  });

  group('.spawn()', () {
    test('should run the given command and return the spawned process', () async {
      var subprocess = childProcess.spawn(process.execPath, ['-v']);
      var stdout = (await asStream<Uint8List>(subprocess.stdout).toList()).single;
      expect(UTF8.decode(stdout).trim(), equals(process.version));
    });
  });

  group('.spawnSync()', () {
    test('should run the given command and return its output', () {
      var result = childProcess.spawnSync(process.execPath, ['-v']);
      expect(result.status, equals(0));
      expect(result.stdout, isList);
      expect(UTF8.decode(result.stdout).trim(), equals(process.version));
    });

    test('should allow different output encodings', () {
      var result = childProcess.spawnSync(process.execPath, ['-v'], new SpawnOptions(encoding: BufferEncoding.utf8));
      expect(result.status, equals(0));
      expect(result.stdout.trim(), equals(process.version));
    });
  });
});

==> nodejs_interop-0.9.0.tar.gz: test/node/child_process/child_process_module_test.dart <==
import 'dart:async';
import 'dart:convert';
import 'dart:js';
import 'dart:typed_data';
import 'package:nodejs_interop/node.dart';
import 'package:test/test.dart';

/// Tests the features of the [ChildProcessModule] class.
void main() => group('ChildProcessModule', () {
  final ChildProcessModule childProcess = require('child_process');

  group('.exec()', () {
    test('should run the given command and return its output', () async {
      var completer = new Completer<String>();
      childProcess.exec('echo fooBar', allowInterop((error, [stdout, stderr]) {
        if (error == null) completer.complete(stdout);
        else completer.completeError(error);
      }));

      var stdout = await completer.future;
      expect(stdout.trim(), equals('fooBar'));
    });

    test('should allow different output encodings', () async {
      var completer = new Completer<Uint8List>();
      var options = new SpawnOptions(encoding: BufferEncoding.buffer);

      childProcess.exec('echo fooBar', options, allowInterop((error, [stdout, stderr]) {
        if (error == null) completer.complete(stdout);
        else completer.completeError(error);
      }));

      var stdout = await completer.future;
      expect(utf8.decode(stdout).trim(), equals('fooBar'));
    });
  });

  group('.execFile()', () {
    test('should run the given command and return its output', () async {
      var completer = new Completer<String>();
      childProcess.execFile(process.execPath, const ['-v'], allowInterop((error, [stdout, stderr]) {
        if (error == null) completer.complete(stdout);
        else completer.completeError(error);
      }));

      var stdout = await completer.future;
      expect(stdout.trim(), equals(process.version));
    });

    test('should allow different output encodings', () async {
      var completer = new Completer<Uint8List>();
      var options = new SpawnOptions(encoding: BufferEncoding.buffer);

      childProcess.execFile(process.execPath, const ['-v'], options, allowInterop((error, [stdout, stderr]) {
        if (error == null) completer.complete(stdout);
        else completer.completeError(error);
      }));

      var stdout = await completer.future;
      expect(utf8.decode(stdout).trim(), equals(process.version));
    });
  });

  group('.execFileSync()', () {
    test('should run the given command and return its output', () {
      Uint8List stdout = childProcess.execFileSync(process.execPath, ['-v']);
      expect(utf8.decode(stdout).trim(), equals(process.version));
    });

    test('should allow different output encodings', () {
      String stdout = childProcess.execFileSync(process.execPath, ['-v'], new SpawnOptions(encoding: BufferEncoding.utf8));
      expect(stdout.trim(), equals(process.version));
    });
  });

  group('.execSync()', () {
    test('should run the given command and return its output', () {
      Uint8List stdout = childProcess.execSync('echo fooBar');
      expect(utf8.decode(stdout).trim(), equals('fooBar'));
    });

    test('should allow different output encodings', () {
      String stdout = childProcess.execSync('echo fooBar', new SpawnOptions(encoding: BufferEncoding.utf8));
      expect(stdout.trim(), equals('fooBar'));
    });
  });

  group('.fork()', () {
    test('should run the given JS module and return the spawned process', () async {
      var subprocess = childProcess.fork('test/fixtures/child_process.js', new SpawnOptions(silent: true));
      expect(subprocess.connected, isTrue);

      var stdout = (await asStream<Uint8List>(subprocess.stdout).toList()).single;
      expect(utf8.decode(stdout).trim(), equals('fooBar'));
    });
  });

  group('.spawn()', () {
    test('should run the given command and return the spawned process', () async {
      var subprocess = childProcess.spawn(process.execPath, ['-v']);
      var stdout = (await asStream<Uint8List>(subprocess.stdout).toList()).single;
      expect(utf8.decode(stdout).trim(), equals(process.version));
    });
  });

  group('.spawnSync()', () {
    test('should run the given command and return its output', () {
      var result = childProcess.spawnSync(process.execPath, ['-v']);
      expect(result.status, equals(0));
      expect(result.stdout, isList);
      expect(utf8.decode(result.stdout).trim(), equals(process.version));
    });

    test('should allow different output encodings', () {
      var result = childProcess.spawnSync(process.execPath, ['-v'], new SpawnOptions(encoding: BufferEncoding.utf8));
      expect(result.status, equals(0));
      expect(result.stdout.trim(), equals(process.version));
    });
  });
});
